<?php

namespace Drupal\field_zip_file\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\field_zip_file\Plugin\Field\FieldType\ZipFileItem;

/**
 * Formatter that shows the file size in a human readable way.
 *
 * @FieldFormatter(
 *   id = "zip_file_base",
 *   label = @Translation("Text"),
 *   field_types = {
 *     "zip_file"
 *   }
 * )
 */
class ZipFileBase extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    $options = parent::defaultSettings();

    $options['default_index'] = NULL;
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);

    $form['default_index'] = [
      '#type' => 'textfield',
      '#title' => $this->t('The default file to open.'),
      '#default_value' => $this->getSetting('default_index'),
      '#description' => $this->t('Sample: index.html. You can leave this empty if your server has configurations to load default index page.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];
    if ($this->getSetting('default_index')) {
      $summary[] = $this->t('Default index page: @index', ['@index' => $this->getSetting('default_index')]);
    }
    return $summary;
  }

  /**
   * Get Url of zip file.
   */
  protected function getUrl(ZipFileItem $zip_file) {
    $url = NULL;
    if ($file = $zip_file->get('entity')->getValue()) {
      if ($file_info = _field_zip_file($file)) {
        $url = file_create_url($file_info['folder_uri']);
      }
    }
    if ($this->getSetting('default_index')) {
      $url = $url . '/' . $this->getSetting('default_index');
    }

    return $url;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];

    foreach ($items as $delta => $item) {
      $elements[$delta] = ['#markup' => $this->getUrl($item)];
    }

    return $elements;
  }

}
