<?php

namespace Drupal\field_zip_file\Plugin\Field\FieldType;

use Drupal\file\Plugin\Field\FieldType\FileItem;

/**
 * Plugin implementation of the 'zip file' field type.
 *
 * @FieldType(
 *   id = "zip_file",
 *   label = @Translation("Zip File"),
 *   description = @Translation("This field stores the ID of an zip file as an integer value."),
 *   category = @Translation("Reference"),
 *   default_widget = "zip_file_widget",
 *   default_formatter = "zip_file_html",
 *   list_class = "\Drupal\file\Plugin\Field\FieldType\FileFieldItemList",
 *   constraints = {"ReferenceAccess" = {}, "FileValidation" = {}}
 * )
 */
class ZipFileItem extends FileItem {

  /**
   * {@inheritdoc}
   */
  public static function defaultFieldSettings() {
    return [
      'file_extensions' => 'zip',
      'file_directory' => '[date:custom:Y]-[date:custom:m]',
      'max_filesize' => '',
      'description_field' => 0,
    ] + parent::defaultFieldSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function onChange($property_name, $notify = TRUE) {
    // Extract the zip file.
    parent::onChange($property_name, $notify);

    if ($file = $this->get('entity')->getValue()) {
      if ($file_info = _field_zip_file($file)) {
        $zipFile = $file_info['zip_file'];
        $folderUri = $file_info['folder_uri'];
        $zipFile->extract($folderUri);
      }
    }
  }

}
