<?php

namespace Drupal\field_zip_file\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\file\Plugin\Field\FieldWidget\FileWidget;
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Plugin implementation of the 'zip_file_widget' widget.
 *
 * @FieldWidget(
 *   id = "zip_file_widget",
 *   label = @Translation("Zip File"),
 *   field_types = {
 *     "zip_file"
 *   }
 * )
 */
class ZipFileWidget extends FileWidget {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);

    $default_fids = $element['#extended'] ? $element['#default_value']['fids'] : $element['#default_value'];
    if (!empty($default_fids)) {
      $element['infos'] = [
        '#type' => 'container',
        '#weight' => 999,
      ];
      foreach ($default_fids as $fid) {
        if ($file = \Drupal::entityTypeManager()
          ->getStorage('file')
          ->load($fid)) {
          if ($file_info = _field_zip_file($file)) {
            $url = Url::fromUri(file_create_url($file_info['folder_uri']), ['attributes' => ['target' => '_blank']]);
            $link = Link::fromTextAndUrl($url->toString(), $url)->toString();
            $element['infos'][] = [
              '#markup' => $this->t('Extracted files are located to: @path', ['@path' => $link]),
            ];
          }
        }
      }
    }

    return $element;
  }

}
